%define _cmake_skip_rpath -DCMAKE_SKIP_RPATH:BOOL=OFF

# Keep libraries private
%if %{_use_internal_dependency_generator}
%define __noautoprov '(.*)\\.so(.*)'
%define __noautoreq 'libdarktable\\.so(.*)'
%endif

Summary:	Utility to organize and develop raw images
Name:		darktable
Version:	2.2.5
Release:	2
License:	GPLv3+
Group:		Graphics
Url:		http://www.darktable.org
#Source0:	https://github.com/darktable-org/darktable/archive/%%{name}-release-%%{version}.tar.gz
Source0:	https://github.com/darktable-org/darktable/releases/download/release-%{version}/%{name}-%{version}.tar.xz
Source1:    darktable_ru.tar.gz
Source100:	%{name}.rpmlintrc
Patch0:		darktable-2.2.0-rpath.patch
BuildRequires:	cmake >= 3.0
BuildRequires:	desktop-file-utils
BuildRequires:	gettext
BuildRequires:	gnome-doc-utils
BuildRequires:	intltool
BuildRequires:	libxml2-utils
# For OpenCL support
BuildRequires:	llvm >= 3.9.0
BuildRequires:	clang >= 3.9.0
BuildRequires:	po4a
BuildRequires:	xml2po
BuildRequires:	xsltproc
BuildRequires:	cups-devel
BuildRequires:	gettext-devel
BuildRequires:	gomp-devel
BuildRequires:	jpeg-devel
BuildRequires:	pugixml-devel >= 1.2
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(colord)
BuildRequires:	pkgconfig(colord-gtk)
BuildRequires:	pkgconfig(dbus-glib-1)
BuildRequires:	pkgconfig(exiv2) >= 0.23
BuildRequires:	pkgconfig(flickcurl)
BuildRequires:	pkgconfig(gconf-2.0)
BuildRequires:	pkgconfig(gdk-pixbuf-2.0)
BuildRequires:	pkgconfig(glib-2.0) >= 2.32
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gnome-keyring-1) >= 3.12.0
BuildRequires:	pkgconfig(GraphicsMagick)
BuildRequires:	pkgconfig(gtk+-3.0) >= 3.12
BuildRequires:	pkgconfig(json-glib-1.0)
BuildRequires:	pkgconfig(lcms2)
BuildRequires:	pkgconfig(lensfun)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libglade-2.0)
BuildRequires:	pkgconfig(libgphoto2) >= 2.5
BuildRequires:	pkgconfig(libopenjpeg1) >= 1.5.0
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(librsvg-2.0)
BuildRequires:	pkgconfig(libsecret-1) >= 0.18
BuildRequires:	pkgconfig(libsoup-2.4)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(libwebp) >= 0.3.0
BuildRequires:	pkgconfig(lua)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(osmgpsmap-1.0) >= 1.1.0
BuildRequires:	pkgconfig(pangocairo)
BuildRequires:	pkgconfig(sdl)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	python-jsonschema

Requires:	gphoto2

%description
Darktable is an open source photography workflow application and RAW developer.
A virtual lighttable and darkroom for photographers. It manages your digital
negatives in a database, lets you view them through a zoomable lighttable
and enables you to develop raw images and enhance them.

%files -f %{name}.lang
%doc doc/README doc/TRANSLATORS
%{_bindir}/%{name}*
%{_libdir}/%{name}
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}
%{_iconsdir}/hicolor/*/apps/%{name}*
%{_mandir}/man1/%{name}*
%{_mandir}/*/man1/%{name}*

#----------------------------------------------------------------------------

%prep
%setup -qn %{name}-%{version}
%patch0 -p1

pushd po
tar -xvzf %{SOURCE1}
popd

rm -fr lua/darktable/external/pygy_require/.gitignore

# Fix clang headers detection
sed -i 's|${LLVM_INSTALL_PREFIX}/lib/clang|${LLVM_INSTALL_PREFIX}/%{_lib}/clang|g' CMakeLists.txt



%build
# FIXME: darktable only supports lua <= 5.2
# For now, we need to use the in-source copy
%cmake \
	-DCMAKE_BUILD_TYPE:STRING=Release \
	-DBINARY_PACKAGE_BUILD:BOOLEAN=ON \
	-DPROJECT_VERSION:STRING="%{name}-%{EVRD}" \
	-DCMAKE_LIBRARY_PATH:PATH=%{_libdir} \
	-DUSE_GNOME_KEYRING:BOOLEAN=OFF \
	-DDONT_USE_INTERNAL_LUA=OFF
%make


%install
%makeinstall_std -C build
desktop-file-install --delete-original \
  --set-key="Exec" --set-value="%{name}" \
  %{buildroot}%{_datadir}/applications/%{name}.desktop

%find_lang %{name}

# We use %%doc macro to pull needed docs
rm -rf %{buildroot}%{_datadir}/doc/%{name}

# Useless stuff making rpmlint complain
rm -rf %{buildroot}%{_datadir}/%{name}/lua/%{name}/external/pygy_require/.gitignore


%changelog

* Sun Sep 10 2017 Victor Ryzhikh <victorr2007@yandex.ru> 2.2.5-2
- (a2632cf) Updated Russian translations
- (Victor Ryzhikh: 6e540ee) Updated Russian translations

* Sun Sep 10 2017 Victor Ryzhikh <victorr2007@yandex.ru> 2.2.5-1
- (6bc17c1) Updated Russian translations
- (Semen Ivanovich: 0b190e0) Updated darktable.spec v2.2.5

* Sat Aug 19 2017 Semen Ivanovich <semivanya5@gmail.com> 2.2.4-1
- (4dfd572) Updated .abf.yml v2.2.5
- (Semen Ivanovich: 3f1a5dc) Updated .abf.yml 2.3.4
- (Semen Ivanovich: d7a6ebb) Updated darktable.spec 2.2.4

* Sat Feb 04 2017 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.2.3-6
- (e77d0e7) MassBuild#1230: Increase release tag

* Thu Feb 02 2017 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.2.3-5
- (f791477) Bump release

* Tue Jan 31 2017 Giovanni Mariani <mc2374@mclink.it> 2.2.3-1
- (a6ce234) Updated to release 2.2.3, workaround lua 5.3 unsupported, enabled OpenCL support

* Mon Dec 26 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.2.0-4
- (5ae18ad) Bump release

* Mon Dec 26 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.2.0-3
- (27b6ba5) Don't use _appdatadir macro because path is hardcoded in build project
- (Andrey Bondrov: 3afa0a4) Fix rpath

* Mon Dec 26 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.2.0-2
- (35e5059) Drop some BuildRequires to save build time

* Sat Dec 24 2016 abfonly <abfonly@gmail.com> 2.2.0-1
- (00b6bc7) fixed docs
- (abfonly: 6ab8189) Log: Update to 2.2.0
- (abfonly: 6ab8189) Changelog: https://github.com/darktable-org/darktable/releases/tag/release-2.2.0

* Mon Nov 07 2016 abfonly <abfonly@gmail.com> 2.0.7-1
- (01be873) Log: Update to 2.0.7
- (01be873) 7-th bugfix release from 2.0 series
- (01be873) more : https://github.com/darktable-org/darktable/releases/tag/release-2.0.7

* Mon Jul 11 2016 abfonly <abfonly@gmail.com> 2.0.5-1
- (e3b826f) Log: Update to 2.0.5
- (e3b826f) build against new osmgpsmap 1.1.0

* Mon Jul 11 2016 Denis Silakov <denis.silakov@rosalab.ru> 2.0.4-2
- (27b0e94) Rebuild.

* Fri May 27 2016 Nemial <negry.m@yandex.ru> 2.0.4-1
- (79c8b5c) Update to 2.0.4

* Mon Apr 18 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.0.3-2
- (2069736) Upload 2.0.3 sources
- (Danie Cillie: 20e30f6) Updated darktable.spec to 2.0.3

* Fri Apr 01 2016 Denis Silakov <denis.silakov@rosalab.ru> 2.0.2-2
- (61d0973) Rebuild with new pugixml

* Fri Mar 18 2016 abfonly <abfonly@gmail.com> 2.0.2-1
- (648c6ee) Log: Update to 2.0.2 -bugfix release
- (648c6ee) General:
- (648c6ee) ---------
- (648c6ee) Require glib of at least version 2.40
- (648c6ee) New features:
- (648c6ee) -------------
- (648c6ee) Add support for DNGs from x3f_extract
- (648c6ee) Support XMP files from Ramperpro timelapse controllers from ElysiaVisuals
- (648c6ee) Bugfixes:
- (648c6ee) ----------
- (648c6ee) Fix some problems with sluggish GUI when Lua is compiled in
- (648c6ee) Some High DPI fixes
- (648c6ee) Small theming fixes
- (648c6ee) Fix some strings being too long in the GUI, especially when using localized versions
- (648c6ee) Fix a potential crash with malformed GPX files
- (648c6ee) Fix wrong zoom level of the map when searching for a location
- (648c6ee) Put XMP metadata into the right Exif fields
- (648c6ee) Fix a crash in masks.
- (648c6ee) Fix a crash in demosaicing
- (648c6ee) Fix Markesteijn demosaicing
- (648c6ee) Fix a crash when moving the mouse while going to darkroom when crop&rotate is active
- (648c6ee) Fix discrepancy between CPU and OpenCL codepath in invert
- (648c6ee) Fix some crashes with certain TIFF files
- (648c6ee) Fix build with GCC6
- (648c6ee) Fix build with osmgpsmap older than 1.1.0
- (648c6ee) Fix compilation when there are spaces in the path names
- (648c6ee) Camera support:
- (648c6ee) ----------------
- (648c6ee) Fujifilm X-Pro2
- (648c6ee) White balance presets:
- (648c6ee) -----------------------
- (648c6ee) Pentax K-S2
- (648c6ee) Noise profiles:
- (648c6ee) ---------------
- (648c6ee) Fujifilm X-T10
- (648c6ee) Pentax K-S2
- (648c6ee) Translations:
- (648c6ee) --------------
- (648c6ee) new:
- (648c6ee) Hebrew
- (648c6ee) updated:
- (648c6ee) German
- (648c6ee) Slovak
- (648c6ee) Swedish
- (648c6ee) Packaging
- (648c6ee) ==========
- (648c6ee) Fixed linting
- (648c6ee) Fixed Hebrew entry in desktop
- (648c6ee) Validate the appdata.xml
- (648c6ee) Spec clean

* Tue Dec 29 2015 gvm <mc2374@mclink.it> 2.0.0-1
- (c9caab4) Fix file list.
- (gvm: 1fd7caa) Fix wrong Breq
- (Giovanni Mariani: 0186149) Updated to release 2.0.0, updated BReqs and file lists, removed now useless things from specfile

* Sun Aug 09 2015 abfonly <abfonly@gmail.com> 1.6.8-1
- (240bad1) Log: update to 1.6.8

* Sat Jul 04 2015 abfonly <abfonly@gmail.com> 1.6.7-1
- (ac27241) Log: Update to 1.6.7, fixed typo
- (Dmitry Ashkadov: c5a12be) Disable gnome-keyring support
- (Dmitry Ashkadov: c5a12be) It seems like developers won't use it, see cmake output:
- (Dmitry Ashkadov: c5a12be) -- GnomeKeyring is only supported for versions older than 3.12.0,
- (Dmitry Ashkadov: c5a12be) version 3.12.0 found. Please use libsecret instead.
- (Dmitry Ashkadov: 28b885f) Update to new version 1.6.7

* Fri Jun 12 2015 Dmitry Ashkadov <dmitry.ashkadov@gmail.com> 1.6.6-2
- (ac52e41) Fix Url tag and url to source0
- (Denis Silakov: 4a37292) Require gphoto2 to be able to manipulate camera (per user request)

* Sun May 17 2015 Giovanni Mariani <mc2374@mclink.it> 1.6.6-1
- (f9f5304) Updated to release 1.6.6

* Tue Apr 21 2015 Giovanni Mariani <mc2374@mclink.it> 1.6.4-1
- (7dd9856) Updated to release 1.6.4


